@@ -15,7 +15,7 @@ class Extractor(QtCore.QObject):
       QtCore.QObject.__init__(self)
 
       self.url = ''
-      self.userAgent = '' #Firefox/3.5 Maemo Browser 1.7.4.8 RX-51 N900'
+      self.userAgent = 'Firefox/3.5 Maemo Browser 1.7.4.8 RX-51 N900'
       self.urlPerturb = ''
       self.rideModel = RideModel(id)
       self.parser = None
