@@ -21,8 +21,12 @@ class SettingsDlg(QtGui.QDialog ):
    def CreateLayouts(self):
       hLayout = QtGui.QHBoxLayout()
       labelnb = QtGui.QLabel('Nombre max de trains par trajet')
-      self.editnb = QtGui.QLineEdit()
-      self.editnb.setText('%d'%self.conf.nbTrains())
+      self.editnb = QtGui.QComboBox()
+      elist = QtCore.QStringList()
+      elist << '1' << '2' << '3' << '4'
+      self.editnb.addItems(elist)
+      idx = elist.indexOf('%d'%self.conf.nbTrains())
+      self.editnb.setCurrentIndex(idx)
       hLayout.addWidget(labelnb)
       hLayout.addWidget(self.editnb)
 
@@ -53,7 +57,7 @@ class SettingsDlg(QtGui.QDialog ):
       self.setLayout(vbox)
 
    def OnOK(self):
-      self.conf.SetNbTrains( self.editnb.text() )
+      self.conf.SetNbTrains( self.editnb.currentText() )
       self.conf.SetRefreshRate( self.refresh.currentText() )
       self.conf.WriteConfig()
       self.accept()
